@@ -11,8 +11,8 @@ import weatherforecastcli.render as render
 import weatherforecastcli.utils as utils
 import weatherforecastcli.config as config
 
-app = typer.Typer(help="Weather forecast CLI.")
-console = Console(style="white on grey15")
+app = typer.Typer(name="weather", help="Weather forecast CLI.")
+console = Console(style="white on grey15", record=True)
 
 
 @app.command()
@@ -31,7 +31,12 @@ def init(
 
 
 @app.command()
-def forecast(location: str, start_date: str | None = None, days: int = 4) -> None:
+def forecast(
+    location: str,
+    start_date: str | None = None,
+    days: int = 4,
+    export_svg: str | None = None,
+) -> None:
     """
     Fetch and display a weather forecast.
     """
@@ -78,6 +83,10 @@ def forecast(location: str, start_date: str | None = None, days: int = 4) -> Non
 
     render.DailyForecastRenderer().render(console, geocoded_location, daily_forecast)
 
+    if export_svg:
+        with open(export_svg, "w") as f:
+            f.write(console.export_svg())
+
 
 def main():
     app()
