@@ -14,20 +14,18 @@ class GeocodedLocation(pydantic.BaseModel):
     latitude: float
     longitude: float
     name: str
+    country_name: str
     country_code: str
     timezone_name: str
     timezone_offset_string: str
 
-    def __str__(self) -> str:
-        return f"{self.name} {self.country_code} ({self.latitude, self.longitude})"
-
 
 def geocode(access_key: str, location_query: str) -> GeocodedLocation:
     response = requests.get(
         "http://api.positionstack.com/v1/forward?"
         f"access_key={access_key}&query={location_query}&timezone_module=1"
     )
-    if response.status_code != 200:
+    if not response.ok:
         try:
             detail = response.json()
         except json.JSONDecodeError:
@@ -39,6 +37,7 @@ def geocode(access_key: str, location_query: str) -> GeocodedLocation:
         latitude=round(geo_data["latitude"], 4),
         longitude=round(geo_data["longitude"], 4),
         name=geo_data["name"],
+        country_name=geo_data["country"],
         country_code=geo_data["country_code"],
         timezone_name=geo_data["timezone_module"]["name"],
         timezone_offset_string=geo_data["timezone_module"]["offset_string"],
